# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401
from pydantic import AnyUrl, Field


class ServiceSpecificationRef(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    ServiceSpecificationRef - a model defined in OpenAPI

        id: The id of this ServiceSpecificationRef.
        href: The href of this ServiceSpecificationRef [Optional].
        name: The name of this ServiceSpecificationRef [Optional].
        version: The version of this ServiceSpecificationRef [Optional].
        base_type: The base_type of this ServiceSpecificationRef [Optional].
        schema_location: The schema_location of this ServiceSpecificationRef [Optional].
        type: The type of this ServiceSpecificationRef [Optional].
        referred_type: The referred_type of this ServiceSpecificationRef [Optional].
    """

    id: str
    href: Optional[AnyUrl] = None
    name: Optional[str] = None
    version: Optional[str] = None
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias='@type')
    referred_type: Optional[str] = Field(default=None, alias='@referredType')


ServiceSpecificationRef.update_forward_refs()
